import { base58 } from "@scure/base";
import { cojsonInternals } from "cojson";
import { PureJSCrypto } from "cojson/dist/crypto/PureJSCrypto"; // Importing from dist to not rely on the exports field
import { Ed } from "react-native-quick-crypto";
const { stableStringify } = cojsonInternals;
const textEncoder = new TextEncoder();
export class RNQuickCrypto extends PureJSCrypto {
    ed;
    constructor() {
        super();
        this.ed = new Ed("ed25519", {});
    }
    static async create() {
        return new RNQuickCrypto();
    }
    newEd25519SigningKey() {
        this.ed.generateKeyPairSync();
        return new Uint8Array(this.ed.getPrivateKey());
    }
    getSignerID(secret) {
        return `signer_z${base58.encode(base58.decode(secret.substring("signerSecret_z".length)))}`;
    }
    sign(secret, message) {
        const signature = new Uint8Array(this.ed.signSync(textEncoder.encode(stableStringify(message)), base58.decode(secret.substring("signerSecret_z".length))));
        return `signature_z${base58.encode(signature)}`;
    }
    verify(signature, message, id) {
        return this.ed.verifySync(base58.decode(signature.substring("signature_z".length)), textEncoder.encode(stableStringify(message)), base58.decode(id.substring("signer_z".length)));
    }
}
//# sourceMappingURL=RNQuickCrypto.js.map