import { LocalNode, RawAccountID } from "cojson";
import { PureJSCrypto } from "cojson/dist/crypto/PureJSCrypto";
import { Account, AgentID, AuthCredentials, AuthSecretStorage, CoValue, CoValueClass, CryptoProvider, ID, NewAccountProps, SessionID, SyncConfig } from "jazz-tools";
import { KvStore } from "./storage/kv-store-context.js";
import type { SQLiteAdapter } from "./storage/sqlite-adapter.js";
import type { RNQuickCrypto } from "./crypto/RNQuickCrypto.js";
export type BaseReactNativeContextOptions = {
    sync: SyncConfig;
    reconnectionTimeout?: number;
    storage?: SQLiteAdapter | "disabled";
    CryptoProvider?: typeof PureJSCrypto | typeof RNQuickCrypto;
    authSecretStorage: AuthSecretStorage;
};
export declare function createJazzReactNativeGuestContext(options: BaseReactNativeContextOptions): Promise<{
    guest: import("jazz-tools").AnonymousJazzAgent;
    node: LocalNode;
    done: () => void;
    logOut: () => Promise<void>;
}>;
export type ReactNativeContextOptions<Acc extends Account> = {
    credentials?: AuthCredentials;
    AccountSchema?: CoValueClass<Acc> & {
        fromNode: (typeof Account)["fromNode"];
    };
    newAccountProps?: NewAccountProps;
    defaultProfileName?: string;
} & BaseReactNativeContextOptions;
export declare function createJazzReactNativeContext<Acc extends Account>(options: ReactNativeContextOptions<Acc>): Promise<{
    me: Acc;
    node: LocalNode;
    authSecretStorage: AuthSecretStorage;
    done: () => void;
    logOut: () => Promise<void>;
}>;
/** @category Auth Providers */
export type SessionProvider = (accountID: ID<Account> | AgentID) => Promise<SessionID>;
export declare function provideLockSession(accountID: ID<Account> | AgentID, crypto: CryptoProvider): Promise<{
    sessionID: `${RawAccountID}_session_z${string}` | `sealer_z${string}/signer_z${string}_session_z${string}`;
    sessionDone: () => void;
}>;
/** @category Invite Links */
export declare function createInviteLink<C extends CoValue>(value: C, role: "reader" | "writer" | "admin", { baseURL, valueHint }?: {
    baseURL?: string;
    valueHint?: string;
}): string;
export declare function setupKvStore(kvStore: KvStore | undefined): KvStore | undefined;
//# sourceMappingURL=platform.d.ts.map