import { JazzContext, JazzContextManagerContext } from "jazz-react-core";
import React, { useEffect, useRef } from "react";
import { ReactNativeContextManager } from "./ReactNativeContextManager.js";
import { setupKvStore } from "./platform.js";
/** @category Context & Hooks */
export function JazzProviderCore({ children, guestMode, sync, storage, AccountSchema, defaultProfileName, onLogOut, kvStore, onAnonymousAccountDiscarded, CryptoProvider, }) {
    setupKvStore(kvStore);
    const [contextManager] = React.useState(() => new ReactNativeContextManager());
    const onAnonymousAccountDiscardedRefCallback = useRefCallback(onAnonymousAccountDiscarded);
    const onLogOutRefCallback = useRefCallback(onLogOut);
    const value = React.useSyncExternalStore(React.useCallback((callback) => {
        const props = {
            AccountSchema,
            guestMode,
            sync,
            storage,
            defaultProfileName,
            onLogOut: onLogOutRefCallback,
            onAnonymousAccountDiscarded: onAnonymousAccountDiscardedRefCallback,
            CryptoProvider,
        };
        if (contextManager.propsChanged(props)) {
            contextManager.createContext(props).catch((error) => {
                console.log(error.stack);
                console.error("Error creating Jazz context:", error);
            });
        }
        return contextManager.subscribe(callback);
    }, [sync, guestMode].concat(storage)), () => contextManager.getCurrentValue(), () => contextManager.getCurrentValue());
    useEffect(() => {
        // In development mode we don't return a cleanup function because otherwise
        // the double effect execution would mark the context as done immediately.
        if (process.env.NODE_ENV === "development")
            return;
        return () => {
            contextManager.done();
        };
    }, []);
    return (<JazzContext.Provider value={value}>
      <JazzContextManagerContext.Provider value={contextManager}>
        {value && children}
      </JazzContextManagerContext.Provider>
    </JazzContext.Provider>);
}
function useRefCallback(callback) {
    const callbackRef = React.useRef(callback);
    callbackRef.current = callback;
    return useRef((...args) => callbackRef.current?.(...args)).current;
}
//# sourceMappingURL=provider.js.map