import type { CojsonInternalTypes, OutgoingSyncQueue, RawCoID, SessionID } from "cojson";
import type { DBClientInterface, SessionRow, SignatureAfterRow, StoredCoValueRow, StoredSessionRow, TransactionRow } from "cojson-storage";
import { SQLiteAdapter } from "./sqlite-adapter.js";
export declare class SQLiteClient implements DBClientInterface {
    private readonly adapter;
    private initializationPromise;
    private isInitialized;
    constructor(adapter: SQLiteAdapter, _: OutgoingSyncQueue);
    private initializeInternal;
    ensureInitialized(): Promise<void>;
    getCoValue(coValueId: RawCoID): Promise<StoredCoValueRow | undefined>;
    getCoValueSessions(coValueRowId: number): Promise<StoredSessionRow[]>;
    getSingleCoValueSession(coValueRowId: number, sessionID: SessionID): Promise<StoredSessionRow | undefined>;
    getNewTransactionInSession(sessionRowId: number, firstNewTxIdx: number): Promise<TransactionRow[]>;
    getSignatures(sessionRowId: number, firstNewTxIdx: number): Promise<SignatureAfterRow[]>;
    addCoValue(msg: CojsonInternalTypes.NewContentMessage): Promise<number>;
    addSessionUpdate({ sessionUpdate, }: {
        sessionUpdate: SessionRow;
    }): Promise<number>;
    addTransaction(sessionRowID: number, nextIdx: number, newTransaction: CojsonInternalTypes.Transaction): Promise<number>;
    addSignatureAfter({ sessionRowID, idx, signature, }: {
        sessionRowID: number;
        idx: number;
        signature: CojsonInternalTypes.Signature;
    }): Promise<number>;
    transaction(operationsCallback: () => unknown): Promise<void>;
}
//# sourceMappingURL=client.d.ts.map